==> haskell-trifecta-2.1.4-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 trifecta
version:              2.1.4
visibility:           public
id:                   trifecta-2.1.4-An81UjhUtVZ5vY8DzxlfLX
key:                  trifecta-2.1.4-An81UjhUtVZ5vY8DzxlfLX
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/trifecta/
synopsis:
    A modern parser combinator library with convenient diagnostics

description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics

    For example:

    <<https://i.imgur.com/ZyzUSSn.png>>

    <images/example.png (Local Copy)>

category:             Text, Parsing, Diagnostics, Pretty Printer, Logging
abi:                  a78a73a1bf87ece505903a04889d1072
exposed:              True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Tutorial Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It

hidden-modules:
    Text.Trifecta.Util.Combinators Text.Trifecta.Util.Pretty

import-dirs:          /usr/lib/ghc-9.4.8/site-local/trifecta-2.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/trifecta-2.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/trifecta-2.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-trifecta
hs-libraries:         HStrifecta-2.1.4-An81UjhUtVZ5vY8DzxlfLX
depends:
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS array-0.5.4.0
    base-4.17.2.1 blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS
    blaze-html-0.9.2.0-Fb0uBay1tjZ9O0f9ZIItN4
    blaze-markup-0.8.3.0-IQaQkzfWNSm9Qm4PDNWXje bytestring-0.11.5.3
    charset-0.3.12-HhXnrqZFGR8ipLYOkGpWE
    comonad-5.0.9-178kmWrlefq4Vhns6stMp9 containers-0.6.7
    deepseq-1.4.8.0 fingertree-0.1.5.0-5B8aiExb8jY6F7p87wjuZy
    ghc-prim-0.9.1 hashable-1.4.4.0-LtdCyz5lRpSEDVfQGtCbHQ
    indexed-traversable-0.1.4-27X1GIy3K3S4C3KcOpuvZH
    lens-5.2.3-7QGQofAPyKYFc2G6dgdqBs mtl-2.2.2
    parsers-0.12.12-3nyhMVxcxoJ9rnBgdjjWM9
    prettyprinter-1.7.1-C5HmRCcNKvH3komkkNnKOd
    prettyprinter-ansi-terminal-1.1.3-GrSGSBDwr8kLyFsmestIN8
    profunctors-5.6.2-LJ401T2PttGGl9FwS0VQ4N
    reducers-3.12.5-1U7ltsM7zS8LTWpC8UMjy transformers-0.5.6.2
    unordered-containers-0.2.20-4tF6VC1d0ODJ0H7AFNioZw
    utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO

haddock-interfaces:   /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html:         /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-trifecta-2.1.4-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 trifecta
version:              2.1.4
visibility:           public
id:                   trifecta-2.1.4-9VLz1pQsiuF1NE8Sz492R1
key:                  trifecta-2.1.4-9VLz1pQsiuF1NE8Sz492R1
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/trifecta/
synopsis:
    A modern parser combinator library with convenient diagnostics

description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics

    For example:

    <<https://i.imgur.com/ZyzUSSn.png>>

    <images/example.png (Local Copy)>

category:             Text, Parsing, Diagnostics, Pretty Printer, Logging
abi:                  070f95cf6400bac13263ea89c18fb6cc
exposed:              True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Tutorial Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It

hidden-modules:
    Text.Trifecta.Util.Combinators Text.Trifecta.Util.Pretty

import-dirs:          /usr/lib/ghc-9.4.8/site-local/trifecta-2.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/trifecta-2.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/trifecta-2.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-trifecta
hs-libraries:         HStrifecta-2.1.4-9VLz1pQsiuF1NE8Sz492R1
depends:
    ansi-terminal-1.0.2-DcWKxdhj5Ak5QW9zDQT4KO array-0.5.4.0
    base-4.17.2.1 blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS
    blaze-html-0.9.2.0-2J5PlDi8Hx1I44gvdzxNcI
    blaze-markup-0.8.3.0-GJRJsJvOT0D2VUgSMRVAnz bytestring-0.11.5.3
    charset-0.3.12-DahlWbIK9eo34OFpm5esw6
    comonad-5.0.9-2Gmso9rweTqIcJUUvmXd6f containers-0.6.7
    deepseq-1.4.8.0 fingertree-0.1.5.0-E4XNHFptaZ2KgZiyvH8qjC
    ghc-prim-0.9.1 hashable-1.4.4.0-9MfualSpDNWnshBkTCGL2
    indexed-traversable-0.1.4-8u6FapWzRE5EZ71WCkwVcL
    lens-5.2.3-ArsxVRMhbU6E8JS3Z9lSQN mtl-2.2.2
    parsers-0.12.12-5wblteRaDWo52PhHbOejPA
    prettyprinter-1.7.1-D3sioF8aQdWB1PWrDshF2j
    prettyprinter-ansi-terminal-1.1.3-8LemWXapcVWIS8NuweYmmX
    profunctors-5.6.2-BsvMv5ivuEWAk9oNCXJExQ
    reducers-3.12.5-E2aBUUdO4ckAHDOaerLlmt transformers-0.5.6.2
    unordered-containers-0.2.20-GHxywVRZMTgDKQfzKfhJsl
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html:         /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
